@@ -26,12 +26,13 @@ from formerbox.data import (
 from formerbox.modules import TokenizerModule, TransformerDataModule, TransformerModule
 from formerbox.optim import AdamW, get_polynomial_decay_with_warmup, weight_decay_params
 from formerbox.tasks import (
+    ByteLevelBPETokenizerFast,
+    ByteLevelBPETokenizerModule,
+    CodeBBPETokenizerFast,
+    CodeBBPETokenizerModule,
     CodeDatasetConverter,
-    CodeTokenizerFast,
-    CodeTokenizerModule,
     TaskModule,
     TransformerTask,
-    TransformerTokenizerFast,
     TransformerTokenizerModule,
 )
 from formerbox.training import TransformerTrainer
